==> net.bluemind.p2.we.settings-4.9.3879.zip: net/bluemind/addressbook/api/gwt/js/JsVCardInfo.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.addressbook.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsVCardInfo extends JavaScriptObject {

	protected JsVCardInfo() {}

	public final native net.bluemind.addressbook.api.gwt.js.JsVCardKind getKind()
	/*-{
	return this["kind"];
	}-*/;

	public final native void setKind(net.bluemind.addressbook.api.gwt.js.JsVCardKind kind)
	/*-{
       this["kind"] = kind;
	}-*/;

	public final native String getMail()
	/*-{
	return this["mail"];
	}-*/;

	public final native void setMail(String mail)
	/*-{
       this["mail"] = mail;
	}-*/;

	public final native String getTel()
	/*-{
	return this["tel"];
	}-*/;

	public final native void setTel(String tel)
	/*-{
       this["tel"] = tel;
	}-*/;

	public final native String getFormatedName()
	/*-{
	return this["formatedName"];
	}-*/;

	public final native void setFormatedName(String formatedName)
	/*-{
       this["formatedName"] = formatedName;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.tag.api.gwt.js.JsTagRef> getCategories()
	/*-{
	return this["categories"];
	}-*/;

	public final native void setCategories(com.google.gwt.core.client.JsArray<net.bluemind.tag.api.gwt.js.JsTagRef> categories)
	/*-{
       this["categories"] = categories;
	}-*/;

	public final native int getMemberCount()
	/*-{
	return this["memberCount"];
	}-*/;

	public final native void setMemberCount(int memberCount)
	/*-{
       this["memberCount"] = memberCount;
	}-*/;

	public final native boolean getPhoto()
	/*-{
	return this["photo"];
	}-*/;

	public final native void setPhoto(boolean photo)
	/*-{
       this["photo"] = photo;
	}-*/;

	public final native String getSource()
	/*-{
	return this["source"];
	}-*/;

	public final native void setSource(String source)
	/*-{
       this["source"] = source;
	}-*/;

	public static native  JsVCardInfo create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}

==> net.bluemind.p2.we.settings-5.4.2760.zip: net/bluemind/addressbook/api/gwt/js/JsVCardInfo.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.addressbook.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsVCardInfo extends JavaScriptObject {

	protected JsVCardInfo() {}

	public final native net.bluemind.addressbook.api.gwt.js.JsVCardKind getKind()
	/*-{
	return this["kind"];
	}-*/;

	public final native void setKind(net.bluemind.addressbook.api.gwt.js.JsVCardKind kind)
	/*-{
       this["kind"] = kind;
	}-*/;

	public final native String getMail()
	/*-{
	return this["mail"];
	}-*/;

	public final native void setMail(String mail)
	/*-{
       this["mail"] = mail;
	}-*/;

	public final native String getTel()
	/*-{
	return this["tel"];
	}-*/;

	public final native void setTel(String tel)
	/*-{
       this["tel"] = tel;
	}-*/;

	public final native String getFormatedName()
	/*-{
	return this["formatedName"];
	}-*/;

	public final native void setFormatedName(String formatedName)
	/*-{
       this["formatedName"] = formatedName;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.tag.api.gwt.js.JsTagRef> getCategories()
	/*-{
	return this["categories"];
	}-*/;

	public final native void setCategories(com.google.gwt.core.client.JsArray<net.bluemind.tag.api.gwt.js.JsTagRef> categories)
	/*-{
       this["categories"] = categories;
	}-*/;

	public final native int getMemberCount()
	/*-{
	return this["memberCount"];
	}-*/;

	public final native void setMemberCount(int memberCount)
	/*-{
       this["memberCount"] = memberCount;
	}-*/;

	public final native boolean getPhoto()
	/*-{
	return this["photo"];
	}-*/;

	public final native void setPhoto(boolean photo)
	/*-{
       this["photo"] = photo;
	}-*/;

	public final native String getSource()
	/*-{
	return this["source"];
	}-*/;

	public final native void setSource(String source)
	/*-{
       this["source"] = source;
	}-*/;

	public final native boolean getHasSecurityKey()
	/*-{
	return this["hasSecurityKey"];
	}-*/;

	public final native void setHasSecurityKey(boolean hasSecurityKey)
	/*-{
       this["hasSecurityKey"] = hasSecurityKey;
	}-*/;

	public static native  JsVCardInfo create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}
